@@ -350,6 +350,9 @@ class PersonMixin(mixins.Human):
 class Person(PersonMixin,Partner):
     """
     Mixin for models that represent a physical person. 
+    
+    See :doc:`/tutorial/human/index`.
+
     """
     class Meta:
         #~ abstract = True
@@ -657,7 +660,8 @@ class PartnerDocument(dd.Model):
     #~ def summary_row(self,ui,rr,**kw):
     def summary_row(self,ar,**kw):
         """
-        A :modmeth:`summary_row` method for partner documents.
+        A :meth:`lino.core.model.Model.summary_row` 
+        method for partner documents.
         """
         href_to = ar.href_to
         #~ href_to = ui.ext_renderer.href_to
