@@ -23,7 +23,7 @@ from __future__ import unicode_literals
 
 from django.conf import settings
 
-from lino.utils.test import TestCase
+from djangosite.utils.test import TestCase
 #from lino.igen import models
 #from lino.modlib.contacts.models import Contact, Companies
 #from lino.modlib.countries.models import Country
@@ -88,7 +88,7 @@ def test01(self):
     and not properly reset.
     """
     
-    if 'en' in babel.AVAILABLE_LANGUAGES:
+    if 'en' in settings.SITE.AVAILABLE_LANGUAGES:
         babel.set_language('en')
         self.assertEquals(luc.address(), u'''\
 Mr Luc SAFFRE
@@ -96,7 +96,8 @@ Uus 1
 Vana-Vigala küla
 78003 Vigala
 Estonia''')
-    if 'de' in babel.AVAILABLE_LANGUAGES:
+
+    if 'de' in settings.SITE.AVAILABLE_LANGUAGES:
         babel.set_language('de')
         self.assertEquals(luc.address(), u'''\
 Herrn Luc SAFFRE
@@ -126,22 +127,27 @@ def test02(self):
     def f(obj): return False
     settings.SITE.is_imported_partner = f
     
+    """
+    Note that we must specify the language both in the user 
+    and in HTTP_ACCEPT_LANGUAGE because...
+    """
+    
     
     luc = Person.objects.get(name__exact="Saffre Luc")
     url = settings.SITE.build_admin_url('api','contacts','Person','%d?query=&an=detail&fmt=json' % luc.pk)
     #~ url = '/api/contacts/Person/%d?query=&an=detail&fmt=json' % luc.pk
-    if 'en' in babel.AVAILABLE_LANGUAGES:
+    if 'en' in settings.SITE.AVAILABLE_LANGUAGES:
         u.language = 'en'
         u.save()
-        response = self.client.get(url,REMOTE_USER='root') # ,HTTP_ACCEPT_LANGUAGE='en')
+        response = self.client.get(url,REMOTE_USER='root',HTTP_ACCEPT_LANGUAGE='en')
         result = self.check_json_result(response,'navinfo disable_delete data id title')
         self.assertEqual(result['data']['country'],"Estonia")
         self.assertEqual(result['data']['gender'],"Male")
     
-    if 'de' in babel.AVAILABLE_LANGUAGES:
+    if 'de' in settings.SITE.AVAILABLE_LANGUAGES:
         u.language = 'de'
         u.save()
-        response = self.client.get(url,REMOTE_USER='root') # ,HTTP_ACCEPT_LANGUAGE='de')
+        response = self.client.get(url,REMOTE_USER='root',HTTP_ACCEPT_LANGUAGE='de')
         result = self.check_json_result(
           response,
           'navinfo disable_delete data id title')
@@ -153,10 +159,10 @@ def test02(self):
         self.assertEqual(df['id'],True)
         
         
-    if 'fr' in babel.AVAILABLE_LANGUAGES:
+    if 'fr' in settings.SITE.AVAILABLE_LANGUAGES:
         u.language = 'fr'
         u.save()
-        response = self.client.get(url,REMOTE_USER='root') # ,HTTP_ACCEPT_LANGUAGE='fr')
+        response = self.client.get(url,REMOTE_USER='root',HTTP_ACCEPT_LANGUAGE='fr')
         result = self.check_json_result(response,'navinfo disable_delete data id title')
         self.assertEqual(result['data']['country'],"Estonie")
         self.assertEqual(result['data']['gender'],u"Masculin")
