@@ -32,11 +32,10 @@ from django.utils.translation import pgettext_lazy
 from django.core.exceptions import ValidationError
 
 from lino.utils.choosers import chooser
-#~ from lino.utils.babel import add_babel_field, babelattr
 from north import babel 
 #~ from lino.utils import dblogger
 
-from lino.utils.instantiator import lookup_or_create
+#~ from lino.utils.instantiator import lookup_or_create
 
 from lino.modlib.contacts import MODULE_LABEL
 
@@ -202,7 +201,7 @@ class City(dd.BabelNamed):
         
     def get_choices_text(self,request,rpt,field):
         names = [self.name]
-        for lng in babel.BABEL_LANGS:
+        for lng in settings.SITE.BABEL_LANGS:
             n = getattr(self,'name_'+lng)
             if n and not n in names:
                 names.append(n)
@@ -294,7 +293,7 @@ class CountryCity(dd.Model):
         Try to auto-create it.
         """
         if self.country is not None:
-            return lookup_or_create(City,City._meta.get_field('name'),text,country=self.country)
+            return City.lookup_or_create('name',text,country=self.country)
             
             #~ qs = self.country.city_set.filter(name__iexact=text)
             #~ if qs.count() == 0:
