@@ -20,7 +20,7 @@ from django.conf import settings
 #~ from lino.utils.instantiator import Instantiator
 
 from lino import dd
-from north import babel
+#~ from north import babel
 from lino.utils import AttrDict
 from lino.utils.restify import restify
 from lino.utils.restify import doc2rst
@@ -28,12 +28,12 @@ from lino.utils.restify import doc2rst
 #~ PAGES = {}
 
 def babelfield(name,language):
-    if language == babel.DEFAULT_LANGUAGE: 
+    if language == settings.SITE.DEFAULT_LANGUAGE: 
         return name
     return name + '_' + language
 
 def page(ref,language,title,body,parent=None,raw_html=False):
-    if not language in babel.AVAILABLE_LANGUAGES:
+    if not language in settings.SITE.AVAILABLE_LANGUAGES:
         return
     pages = dd.resolve_app('pages',strict=True)
     obj = pages.lookup(ref,None)
