@@ -586,12 +586,12 @@ def on_login(request,user):
     because those don't have request data
     (is that still true in Django 1.5)
     """
-    
+    #~ logger.info("20130313 on_login(%s)" % user)
     request.user = user
     
         
-    #~ if len(babel.AVAILABLE_LANGUAGES) > 1:
-    if len(settings.SITE.languages) > 1:
+    if len(settings.SITE.AVAILABLE_LANGUAGES) > 1:
+    #~ if settings.SITE.languages != None and len(settings.SITE.languages) > 1:
         
         #~ lang = settings.SITE.override_user_language() or request.user.language
         lang = user.language
@@ -618,7 +618,9 @@ def on_login(request,user):
         #~ request.requesting_panel = None
         #~ return
         
-    if len(settings.SITE.languages) > 1:
+    if len(settings.SITE.AVAILABLE_LANGUAGES) > 1:
+    #~ if settings.SITE.languages != None and len(settings.SITE.languages) > 1:
+      
         ul = rqdata.get(constants.URL_PARAM_USER_LANGUAGE,None)
         if ul:
             translation.activate(ul)
@@ -661,11 +663,13 @@ class RemoteUserMiddleware(object):
     
     def process_request(self, request):
       
-        settings.SITE.startup() # trigger site startup if necessary
-        
+        #~ settings.SITE.startup() # trigger site startup if necessary
         username = request.META.get(
             settings.SITE.remote_user_header,settings.SITE.default_user)
             
+        if not username:
+            raise Exception("Using remote authentication, but no user credentials found.")
+            
         user = authenticate(username)
         
         if user is None:
@@ -681,7 +685,9 @@ class SessionUserMiddleware(object):
 
     def process_request(self, request):
       
-        settings.SITE.startup() # trigger site startup if necessary
+        #~ print 20130313, request.session.get('username')
+        
+        #~ settings.SITE.startup() # trigger site startup if necessary
         
         user = authenticate(request.session.get('username'),
             request.session.get('password'))
@@ -697,7 +703,7 @@ class NoUserMiddleware(object):
   
     def process_request(self, request):
       
-        settings.SITE.startup() # trigger site startup if necessary
+        #~ settings.SITE.startup() # trigger site startup if necessary
         
         user = AnonymousUser.instance()
         
